@@ -4,7 +4,7 @@ define([
 	'backbone',
 ], function(_, Backbone) {
 
-	return Backbone.Model.extend({
+	var CredentialSetModel = Backbone.Model.extend({
 
 		urlRoot: "api/credentialsets",
 
@@ -16,8 +16,16 @@ define([
 			'password': "=",
 			'superPassword': "=",
 			'publicKey': "",
-			'privateKey': ""
+			'privateKey': "",
+			'username': "",
+			'authType': "SHA",
+			'authKey': "",
+			'privType': "DES",
+			'privKey': ""
 		},
+		
+		authTypes: ["MD5", "SHA"],
+		privTypes: ["DES", "AES128", "AES192", "AES256"],
 
 		cleanUp: function(attrs) {
 			var type = (typeof attrs['type'] == 'undefined' ? this.get('type') : attrs['type']);
@@ -27,9 +35,12 @@ define([
 				'name',
 				'mgmtDomain'
 			];
-			if (type.match(/SNMP/i)) {
+			if (type.match(/SNMP v(1|2)/i)) {
 				selAttrs.push('community');
 			}
+			else if ( type.match(/SNMP v3/i)) {  
+				selAttrs.push('username', 'authType', 'authKey' , 'privType', 'privKey');
+			}
 			else if (type.match(/(Telnet|SSH)/i)) {
 				selAttrs.push('username', 'password', 'superPassword');
 				if (type.match(/Key/)) {
@@ -48,4 +59,6 @@ define([
 
 	});
 
+	return CredentialSetModel;
+
 });
