@@ -7,11 +7,13 @@ define([
 	return Backbone.Model.extend({
 
 		initialize: function(options) {
-			this.group = options.group;
+			this.groups = options.groups;
 			this.domains = options.domains;
-			this.interfaces = options.interfaces;
-			this.inventory = options.inventory;
-			this.locations = options.locations;
+			this.exportGroups = options.exportGroups;
+			this.exportInterfaces = options.exportInterfaces;
+			this.exportInventory = options.exportInventory;
+			this.exportLocations = options.exportLocations;
+			this.exportCompliance = options.exportCompliance;
 		},
 
 		getDownloadUrl: function() {
@@ -25,23 +27,30 @@ define([
 					params.push("domain=" + domain);
 				});
 			}
-			if (typeof this.group !== "undefined") {
-				params.push("group=" + this.group);
+			if (this.groups) {
+				_.forEach(this.groups, function(group) {
+					params.push("group=" + group);
+				});
 			}
-			if (this.interfaces) {
+			if (this.exportGroups) {
+				params.push("groups=true");
+			}
+			if (this.exportInterfaces) {
 				params.push("interfaces=true");
 			}
-			if (this.inventory) {
+			if (this.exportInventory) {
 				params.push("inventory=true");
 			}
-			if (this.locations) {
+			if (this.exportLocations) {
 				params.push("locations=true");
 			}
+			if (this.exportCompliance) {
+				params.push("compliance=true");
+			}
 			if (params.length) {
 				url += "?" + params.join("&");
 			}
 			return url;
-			return this.urlRoot + '?' + $.param(this.attributes);
 		}
 
 	});
