@@ -17,7 +17,10 @@ define([
 		},
 
 		buttons: {
-			"Confirm": function(event) {
+			"Cancel": function() {
+				this.close();
+			},
+			"Delete": function(event) {
 				var that = this;
 				var $button = $(event.target).closest("button");
 				$button.button('disable');
@@ -31,9 +34,6 @@ define([
 					that.$("#error").show();
 					$button.button('enable');
 				});
-			},
-			"Cancel": function() {
-				this.close();
 			}
 		}
 
