@@ -23,7 +23,10 @@ define([
 		},
 
 		buttons: {
-			"Confirm": function(event) {
+			"Cancel": function() {
+				this.close();
+			},
+			"Delete": function(event) {
 				var that = this;
 				that.$('button').button('disable');
 				var $button = $(event.target).closest('button');
@@ -58,9 +61,6 @@ define([
 					});
 				};
 				startNext();
-			},
-			"Cancel": function() {
-				this.close();
 			}
 		},
 
