@@ -39,11 +39,13 @@ define([
 			}).click(function() {
 				ReportView.defaultOptions.domain = that.$('#filterdomain').prop('checked') ? that.$('#domain').val() : undefined;
 				var exportParams = new DataExportReportParamsModel({
-					group: (that.$('#filtergroup').prop('checked') ? that.$('#group').val() : -1),
-					domains: (that.$('#filterdomain').prop('checked') ? that.$('#domain').val() : -1),
-					interfaces: that.$('#filterinterfaces').prop('checked'),
-					inventory: that.$('#filterinventory').prop('checked'),
-					locations: that.$('#filterlocations').prop('checked'),
+					groups: (that.$('#filtergroup').prop('checked') ? [that.$('#group').val()] : undefined),
+					domains: (that.$('#filterdomain').prop('checked') ? [that.$('#domain').val()] : undefined),
+					exportGroups: that.$('#exportgroups').prop('checked'),
+					exportInterfaces: that.$('#exportinterfaces').prop('checked'),
+					exportInventory: that.$('#exportinventory').prop('checked'),
+					exportLocations: that.$('#exportlocations').prop('checked'),
+					exportCompliance: that.$('#exportcompliance').prop('checked'),
 				});
 				window.location = exportParams.getDownloadUrl();
 				return false;
